var indexSectionsWithContent =
{
  0: "3_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghijklmnopqrstuvx",
  2: "sv",
  3: "abcdefghiklmnoprstuv",
  4: "_abcdefghijklmnopqrstuvwx~",
  5: "abcdefghiklmnopqrstuvwxyz",
  6: "abcdefghiklmnopstuv",
  7: "abcdefikmnoprstuv",
  8: "cfklmnrstwz",
  9: "w",
  10: "abcdefhklmnopstvw",
  11: "3abcdfghimoprstuvw",
  12: "3eipv"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

